@@ -3,13 +3,12 @@ def get_version():
     import pathlib
 
     cp = configparser.ConfigParser()
-    # Python 3.5 ConfigParser does not accept Path as filename
-    cp.read(str(pathlib.Path(__file__).parent.parent / "setup.cfg"))
+    cp.read(pathlib.Path(__file__).parent.parent / "setup.cfg")
     return cp["metadata"]["version"]
 
 
 project = "uritools"
-copyright = "2014-2021 Thomas Kemmer"
+copyright = "2014-2022 Thomas Kemmer"
 version = get_version()
 release = version
 
